#ifndef EL__ECMASCRIPT_MUJS_IMPLEMENTATION_H
#define EL__ECMASCRIPT_MUJS_IMPLEMENTATION_H

#include <mujs.h>

#ifdef __cplusplus
extern "C" {
#endif

void mjs_push_implementation(js_State *J);

#ifdef __cplusplus
}
#endif

#endif



